@@ -1,12 +1,12 @@
 import kate
 
-from kate_core_plugins import insertText, setSelectionFromCurrentPosition
+from kate_core_plugins import insertText, TEXT_TO_CHANGE
 from kate_settings_plugins import KATE_ACTIONS
 
 TEXT_JQUERY = """<script type="text/javascript">
     (function($){
         $(document).ready(function () {
-            $("XXX").click(function(){
+            $("%s").click(function(){
                 // Write here
             });
         });
@@ -17,7 +17,4 @@ TEXT_JQUERY = """<script type="text/javascript">
 
 @kate.action(**KATE_ACTIONS['insertReady'])
 def insertReady():
-    view = kate.activeView()
-    pos = view.cursorPosition()
-    insertText(TEXT_JQUERY, start_in_current_column=True)
-    setSelectionFromCurrentPosition(pos, (3, 15), (3, 18))
+    insertText(TEXT_JQUERY % TEXT_TO_CHANGE, start_in_current_column=True)
